'use strict';

require('./curry.js');
var __chunk_1 = require('./chunk-6c48b316.js');
require('./chunk-046be687.js');
require('./_append.js');
require('./append.js');
require('./flip.js');
var __chunk_3 = require('./chunk-40161f88.js');
var array = require('./array.js');
var _fold = require('./_fold.js');
require('./_randomInt.js');
var randomInt = require('./randomInt.js');

/**
 * Shuffles a list using the [Fisher-Yates
 * algorithm](http://en.wikipedia.org/wiki/Fisher-Yates_shuffle).
 *
 * @param {Array|String} as The list.
 * @returns {Array|String} A list that contains the elements in the list of
 * `as` randomly shuffled.
 * @example
 *
 * import { shuffle } from 'fkit'
 * shuffle([1, 2, 3]) // [2, 3, 1]
 * shuffle('abc') // 'bca'
 */
function shuffle (as) {
  let i = -1;

  const f = (b, a) => {
    const j = randomInt(0, ++i);

    b[i] = b[j];
    b[j] = a;

    return b
  };

  const r = array(as.length);
  const bs = _fold(f, r, as);
  const s = __chunk_1.isString(as) ? '' : [];

  return __chunk_3.concatWith(s, bs)
}

module.exports = shuffle;
