'use strict';

require('./curry.js');
var __chunk_1 = require('./chunk-6c48b316.js');
require('./chunk-046be687.js');
require('./variadic.js');
require('./_append.js');
require('./append.js');
require('./flip.js');
require('./chunk-40161f88.js');
var __chunk_4 = require('./chunk-acf1cc79.js');
var concat = require('./concat.js');
var empty = require('./empty.js');
var head = require('./head.js');
var tail = require('./tail.js');
require('./_prepend.js');
var _foldRight = require('./_foldRight.js');
var prepend = require('./prepend.js');

/**
 * Returns `a` in a pure context.
 *
 * @private
 */
function pure (a) {
  return __chunk_1.isString(a) || __chunk_4.isArrayOfStrings(a) ? a : [a]
}

/**
 * Calculates the subsequences of a list.
 *
 * @param {Array|String} as The list.
 * @returns {Array} A list that contains all the subsequences of the elements
 * in the list of `as`.
 * @example
 *
 * import { subsequences } from 'fkit'
 * subsequences([1, 2, 3]) // [[], [1], [2], [1, 2], [3], [1, 3], [2, 3], [1, 2, 3]]
 * subsequences('abc') // ['', 'a', 'b', 'ab', 'c', 'ac', 'bc', 'abc']
 */
function subsequences (as) {
  const subsequences_ = bs => {
    const b = head(bs);
    const f = (ys, r) => concat(pure(ys), pure(prepend(b, ys)), r);

    if (empty(bs)) {
      return []
    } else {
      return prepend(pure(b), _foldRight(f, [], subsequences_(tail(bs))))
    }
  };

  return prepend(__chunk_4.mempty(as), subsequences_(as))
}

module.exports = subsequences;
