'use strict';

var curry = require('./curry.js');
require('./always.js');
require('./_branch.js');
require('./branch.js');
require('./id.js');
require('./chunk-6c48b316.js');
require('./chunk-046be687.js');
require('./variadic.js');
require('./compose.js');
require('./_append.js');
require('./append.js');
require('./flip.js');
require('./chunk-40161f88.js');
require('./chunk-acf1cc79.js');
require('./concat.js');
require('./_concatMap.js');
require('./_filter.js');
require('./_any.js');
require('./_fold.js');
var _unionBy = require('./_unionBy.js');

/**
 * Calculates the union of two lists.
 *
 * The comparator function `f` compares two elements, `a` and `b`. If the
 * elements are both considered to equal, then the comparator function should
 * return `true`. Otherwise it should return `false`.
 *
 * Duplicates are removed from `bs`, but if `as` contains duplicates then so
 * will the result.
 *
 * @function
 * @param {Function} f The comparator function.
 * @param {Array|String} as The first list.
 * @param {Array|String} bs The second list.
 * @returns {Array|String} A list that contains the union of elements in the
 * lists of `as` and `bs`.
 * @example
 *
 * import { unionBy } from 'fkit'
 * unionBy((a, b) => a === b, [1, 2, 3], [2, 3, 4]) // [1, 2, 3, 4]
 * unionBy((a, b) => a === b, 'hello', 'world') // 'hellowrd'
 */
var unionBy = curry(_unionBy);

module.exports = unionBy;
